c.....
c     Program to calculate differential neutron albedo based
c     on calculated parameters
c.....
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      CHARACTER img1(13)*12
      common /alpha2C/ PP(13,24)
c.....
c     Set the material type.
c     1=concrete
c     2=iron
c     3=lead
c     4=water
c.....
      do 100 i=1,5
        write(*,*) 'Select a material (1=concrete, 2=Fe, 3=Pb,',
     &        ' or 4=water):'
        read(*,*) imat
        if((imat.lt.1).or.(imat.gt.4)) then
           write(*,*) 'Material selection must be between 1 and 4.'
                else
                   goto 200
                endif
 100  continue
c.....
c     Set the response type.
c     1=eff. dose in anth. phantom (PA geometry)
c     2=ambient dose equivalent
c     3=henderson response.
c.....
 200  do 300 i=1,5
        write(*,*) 'Select a response: (1=AP effective dose, 2=ambient',
     &             ' dose, or 3=henderson):'
        read(*,*) ires
        if((ires.lt.1).or.(ires.gt.3)) then
           write(*,*) 'Response selection must be between 1 and 3.'
                else
                   goto 400
                endif
 300  continue
c.....
c     Read in albedo fit paramters.
c.....
 400  if((imat.eq.1).AND.(ires.eq.1)) then
         OPEN(25,FILE='1aconc.txt')
      elseif((imat.eq.2).AND.(ires.eq.1)) then
         OPEN(25,FILE='1airon.txt')
      elseif((imat.eq.3).AND.(ires.eq.1)) then
         OPEN(25,FILE='1alead.txt')
      elseif((imat.eq.4).AND.(ires.eq.1)) then
         OPEN(25,FILE='1awater.txt')
      elseif((imat.eq.1).AND.(ires.eq.2)) then
         OPEN(25,FILE='2aconc.txt')
      elseif((imat.eq.2).AND.(ires.eq.2)) then
         OPEN(25,FILE='2airon.txt')
      elseif((imat.eq.3).AND.(ires.eq.2)) then
         OPEN(25,FILE='2alead.txt')
      elseif((imat.eq.4).AND.(ires.eq.2)) then
         OPEN(25,FILE='2awater.txt')
      elseif((imat.eq.1).AND.(ires.eq.3)) then
         OPEN(25,FILE='3aconc.txt')
      elseif((imat.eq.2).AND.(ires.eq.3)) then
         OPEN(25,FILE='3airon.txt')
      elseif((imat.eq.3).AND.(ires.eq.3)) then
         OPEN(25,FILE='3alead.txt')
      elseif((imat.eq.4).AND.(ires.eq.3)) then
         OPEN(25,FILE='3awater.txt')
      end if
c.....
c     Read in the number of energies in input
c.....
      READ(25,*) intEne
c.....
c     Read in parameters for selected material and display
c     the energy groups.
c.....
      write(*,*) 'Select an energy group from the list below'
      do 998 i=1,intEne
        READ(25,'(a)') img1(i)
            write(*,999) i,img1(i)
        READ(25,*) PP(i,1),PP(i,2),PP(i,3),PP(i,4),PP(i,5),PP(i,6)
        READ(25,*) PP(i,7),PP(i,8),PP(i,9),PP(i,10),PP(i,11),PP(i,12)
        READ(25,*) PP(i,13),PP(i,14),PP(i,15),PP(i,16),PP(i,17),PP(i,18)
        READ(25,*) PP(i,19),PP(i,20),PP(i,21),PP(i,22),PP(i,23),PP(i,24)
 998  continue
 999  FORMAT(1X,'(',I2, ').  ', 1X, A)
c.....
c     Select the appropriate energy range.
c.....
      read(*,*) iEnerg
c.....
c     set the angles for the calculation
c.....
          do 1000 i=1,5
         write(*,*) 'Enter the angle (theta0,theta,psi) in degrees:'
         read(*,*) ang0, ang, psi
         if((ang0.lt.0d0).or.(ang0.gt.90.0d0)) then
           write(*,*) 'Incident polar angle must be between 0 and 90.'
                 elseif((ang.lt.0d0).or.(ang0.gt.90.0d0)) then
           write(*,*) 'Emergent polar angle must be between 0 and 90.'
                 elseif((psi.lt.0d0).or.(psi.gt.180.0d0)) then
           write(*,*) 'Emergent psi angle must be between 0 and 180.'
                 else
                   goto 2000
                 endif
 1000 continue
c.....
c     Get the angle cosines.
c.....
 2000 cang0 = DCOS(3.141592654d0*ang0/180.0d0)
      cang = DCOS(3.141592654d0*ang/180.0d0)
      cpsi = DCOS(3.141592654d0*psi/180.0d0)
c.....
c     Calculate the albedo.
c.....
      call alpha3(cang0,cang,cpsi,retVal,iEnerg)
c.....
c     Display the result.
c.....
      write(*,*) retVal

      CLOSE(25)
c.....
c     program termination.
c.....
      end
c.....
c     Routine to calculate the double differentail abledo
c.....
      subroutine alpha3(cang0,cang,cpsi,retVal,iE)
c        run the complete history of a source particle.
      implicit double precision (a-h,o-z)
c
      common /alpha2C/ PP(13,24)
      DIMENSION B(0:12),AA(0:2,0:2),P(0:12)
C.......
C       Apply the albedo approximation to obtain the
C       thermal neutron albedo.
C.......
          DO 100 I=0,12
            B(I)=PP(iE,I+1)
  100     CONTINUE
          AA(0,0)=PP(iE,14)
          AA(0,1)=PP(iE,15)
          AA(0,2)=PP(iE,16)
          AA(1,0)=PP(iE,17)
          AA(1,1)=PP(iE,18)
          AA(1,2)=PP(iE,19)
          AA(2,0)=PP(iE,20)
          AA(2,1)=PP(iE,21)
          AA(2,2)=PP(iE,22)
C.........
C         SET UP THE EQUATION.
C.........
          X2=0.0D0
          DO 111 I=0,2
            XDUM=0.0D0
            DO 110 J=0,2
               XDUM=XDUM+AA(I,J)*(CANG0**J)
 110        CONTINUE
            X2=X2+XDUM*((ABS(CANG))**I)
 111      CONTINUE
          X3=ABS(CANG)/(ABS(CANG)+X2)
C          CDX = -CANG0*CANG +
C     1       DSQRT(1.D0-CANG0*CANG0)*DSQRT(1.D0-CANG*CANG)*CPSI
          CDX=-CANG0*CANG + CPSI*SIN(ACOS(CANG0))*SIN(ACOS(CANG))
C.........
C         EVALUATE THE LEGENDRE POLYNOMIAL TO ORDER EIGHT.
C.........
          P(0)=1.0D0
          P(1)=CDX
          DO 112 I=2,12
            P(I)=2.0D0*CDX*P(I-1)-P(I-2)-(CDX*P(I-1)-P(I-2))/I
 112      CONTINUE
          X4=0.0D0
          X5=0.0D0
          DO 114 i=0,12
            X5=X5+B(I)*P(I)
 114      CONTINUE
          CALL hfn(PP(iE,23),CANG0,X93)
          CALL hfn(PP(iE,24),CANG,X94)
C.........
C         Piece together the parts to get the albedo.
C.........
          retVal=X3*X5*X93*X94
      return
      end
c.....
c     Approximation of the H function.
c.....
      subroutine hfn(c, mu, hmu)
      implicit double precision (a-h,m-z)
      A1 = 0.075272288D0
      A2 = -0.063133359D0
      A3 = 0.021092012D0
      A4 = -0.026070382D0
      A5 = 0.0093816804D0
      A6 = -3.1792793D0
      A7 = 3.4857398D0
      A8 = -1.2949887D0
      A9 = -0.0057504178D0
      X1 = A1+A2*c+A3*mu+A4*(mu**2)+A5*(mu**3)
      X2 = 1.0D0+A6*c+A7*(c**2)+A8*(c**3)+A9*mu
      hmu = X1/X2
      return
      end

